summaryrefslogtreecommitdiffstats
path: root/src/devices/pic/base/pic_config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/pic/base/pic_config.h')
-rw-r--r--src/devices/pic/base/pic_config.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/src/devices/pic/base/pic_config.h b/src/devices/pic/base/pic_config.h
index 185a19e..67c0b1c 100644
--- a/src/devices/pic/base/pic_config.h
+++ b/src/devices/pic/base/pic_config.h
@@ -9,8 +9,8 @@
#ifndef PIC_CONFIG_H
#define PIC_CONFIG_H
-#include <qmap.h>
-#include <qstringlist.h>
+#include <tqmap.h>
+#include <tqstringlist.h>
#include "common/common/bitvalue.h"
#include "pic_protection.h"
@@ -29,8 +29,8 @@ class Config
public:
class Value {
public:
- QString name;
- QMap<ConfigNameType, QStringList> configNames;
+ TQString name;
+ TQMap<ConfigNameType, TQStringList> configNames;
BitValue value;
bool operator <(const Value &cv) const { return value<cv.value; }
bool isValid() const { return !name.isEmpty(); }
@@ -38,33 +38,33 @@ public:
class Mask {
public:
- QString name;
+ TQString name;
BitValue value;
- QValueVector<Value> values; // ordered from lower to higher
+ TQValueVector<Value> values; // ordered from lower to higher
bool operator <(const Mask &cm) const { return value<cm.value; }
};
class Word {
public:
- QString name;
- QStringList ignoredCNames;
- BitValue wmask, pmask, cmask; // write, protected, and checksum bits masks
+ TQString name;
+ TQStringList ignoredCNames;
+ BitValue wtqmask, ptqmask, ctqmask; // write, protected, and checksum bits tqmasks
BitValue bvalue; // blank value
- QValueVector<Mask> masks; // ordered from lower to higher
+ TQValueVector<Mask> tqmasks; // ordered from lower to higher
BitValue usedMask() const;
};
public:
Config(const Pic::Data &data) : _data(data), _protection(data, *this) {}
- QValueVector<Word> _words;
+ TQValueVector<Word> _words;
const Protection &protection() const { return _protection; }
- const Value *findValue(const QString &mask, const QString &value) const;
- const Mask *findMask(const QString &mask, uint *wordIndex = 0) const;
- static bool hasMaskName(const QString &mask);
- static QString maskLabel(const QString &mask);
- bool checkValueName(const QString &mask, const QString &name) const;
- static QString valueLabel(const QString &mask, const QString &name);
+ const Value *findValue(const TQString &tqmask, const TQString &value) const;
+ const Mask *findMask(const TQString &tqmask, uint *wordIndex = 0) const;
+ static bool hasMaskName(const TQString &tqmask);
+ static TQString tqmaskLabel(const TQString &tqmask);
+ bool checkValueName(const TQString &tqmask, const TQString &name) const;
+ static TQString valueLabel(const TQString &tqmask, const TQString &name);
private:
class MapData {
@@ -73,8 +73,8 @@ private:
MapData(int i, int b) : index(i), block(b) {}
int index, block;
};
- static QMap<QString, MapData> &masks();
- static QMap<QString, MapData> *_masks; // mask name -> index in DATA
+ static TQMap<TQString, MapData> &tqmasks();
+ static TQMap<TQString, MapData> *_tqmasks; // tqmask name -> index in DATA
struct NameData {
const char *name, *label;
@@ -82,7 +82,7 @@ private:
enum Type { Fixed, ValueDouble, ValueUInt, Ratio, MemoryRange, Toggle, Pin, Pins };
class Data {
public:
- const NameData mask;
+ const NameData tqmask;
Type type;
const NameData values[50];
};
@@ -93,14 +93,14 @@ private:
Protection _protection;
};
-QDataStream &operator <<(QDataStream &s, const Config::Value &value);
-QDataStream &operator >>(QDataStream &s, Config::Value &value);
-QDataStream &operator <<(QDataStream &s, const Config::Mask &mask);
-QDataStream &operator >>(QDataStream &s, Config::Mask &mask);
-QDataStream &operator <<(QDataStream &s, const Config::Word &word);
-QDataStream &operator >>(QDataStream &s, Config::Word &word);
-QDataStream &operator <<(QDataStream &s, const Config &config);
-QDataStream &operator >>(QDataStream &s, Config &config);
+TQDataStream &operator <<(TQDataStream &s, const Config::Value &value);
+TQDataStream &operator >>(TQDataStream &s, Config::Value &value);
+TQDataStream &operator <<(TQDataStream &s, const Config::Mask &tqmask);
+TQDataStream &operator >>(TQDataStream &s, Config::Mask &tqmask);
+TQDataStream &operator <<(TQDataStream &s, const Config::Word &word);
+TQDataStream &operator >>(TQDataStream &s, Config::Word &word);
+TQDataStream &operator <<(TQDataStream &s, const Config &config);
+TQDataStream &operator >>(TQDataStream &s, Config &config);
} //namespace